==> vue-dialog-box-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/dialog-box/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { iconClose, iconFullscreen, iconMinscreen } from "@dftvue2-opentiny/vue-icon";
import "@dftvue2-opentiny/vue-theme/dialog-box/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconClose: iconClose(),
    IconFullscreen: iconFullscreen(),
    IconMinscreen: iconMinscreen()
  },
  emits: ["update:visible", "change", "before-close", "open", "close", "opened", "confirm", "cancel", "closed", "drag-start", "drag-move", "drag-end"],
  props: [].concat(props, ["resize", "isFormReset", "visible", "title", "modal", "modalAppendToBody", "appendToBody", "lockScroll", "closeOnClickModal", "closeOnPressEscape", "showClose", "width", "fullscreen", "top", "center", "draggable", "showHeader", "rightSlide", "destroyOnClose", "dialogClass", "beforeClose", "maxHeight"]),
  model: {
    prop: "visible",
    event: "update:visible"
  },
  provide: function provide() {
    return {
      dialog: this
    };
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": _vm.state.animationName
    },
    on: {
      "after-enter": _vm.afterEnter,
      "after-leave": _vm.afterLeave
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    class: ["tiny-dialog-box__wrapper", _vm.dialogClass],
    on: {
      "click": function click($event) {
        if ($event.target !== $event.currentTarget)
          return null;
        return _vm.handleWrapperClick.apply(null, arguments);
      }
    }
  }, [(_vm.destroyOnClose ? _vm.visible : true) ? _c("div", {
    key: _vm.state.key,
    ref: "dialog",
    staticClass: "tiny-dialog-box",
    class: [{
      "is-fullscreen": _vm.state.isFull,
      "is-center": _vm.center,
      "is-right-slide": _vm.rightSlide
    }],
    style: _vm.state.style
  }, [_vm.showHeader ? _c("div", {
    staticClass: "tiny-dialog-box__header",
    on: {
      "mousedown": _vm.handleDrag
    }
  }, [_vm._t("title", function() {
    return [_c("span", {
      staticClass: "tiny-dialog-box__title"
    }, [_vm._v(_vm._s(_vm.title))])];
  }), _vm.showClose ? _c("button", {
    staticClass: "tiny-dialog-box__headerbtn",
    attrs: {
      "type": "button",
      "aria-label": "Close"
    },
    on: {
      "click": function click($event) {
        return _vm.handleClose("close", $event);
      }
    }
  }, [_c("icon-close", {
    staticClass: "tiny-svg-size tiny-dialog-box__close"
  })], 1) : _vm._e(), _vm.resize && !_vm.state.isFull ? _c("button", {
    staticClass: "tiny-dialog-box__headerbtn",
    attrs: {
      "type": "button",
      "aria-label": "Resize"
    },
    on: {
      "click": function click($event) {
        _vm.state.isFull = true;
      }
    }
  }, [_c("icon-fullscreen", {
    staticClass: "tiny-svg-size tiny-dialog-box__close"
  })], 1) : _vm._e(), _vm.resize && _vm.state.isFull ? _c("button", {
    staticClass: "tiny-dialog-box__headerbtn",
    attrs: {
      "type": "button",
      "aria-label": "Resize"
    },
    on: {
      "click": function click($event) {
        _vm.state.isFull = false;
      }
    }
  }, [_c("icon-minscreen", {
    staticClass: "tiny-svg-size tiny-dialog-box__close"
  })], 1) : _vm._e()], 2) : _vm._e(), _c("div", {
    staticClass: "tiny-dialog-box__body",
    style: _vm.state.bodyStyle
  }, [_vm._t("default")], 2), _vm.slots.footer ? _c("div", {
    staticClass: "tiny-dialog-box__footer"
  }, [_vm._t("footer", null, {
    "beforeClose": _vm.beforeClose
  })], 2) : _vm._e()]) : _vm._e()])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-dialog-box-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/dialog-box/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconClose, iconFullscreen, iconMinscreen } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/dialog-box/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconClose: iconClose(),
    IconFullscreen: iconFullscreen(),
    IconMinscreen: iconMinscreen()
  },
  emits: [
    "update:visible",
    "change",
    "before-close",
    "open",
    "close",
    "opened",
    "confirm",
    "cancel",
    "closed",
    "drag-start",
    "drag-move",
    "drag-end",
    // tiny 新增
    "resize"
  ],
  props: [].concat(props, ["resize", "isFormReset", "visible", "title", "modal", "modalAppendToBody", "appendToBody", "lockScroll", "closeOnClickModal", "closeOnPressEscape", "showClose", "width", "fullscreen", "top", "center", "draggable", "dragOutsideWindow", "showHeader", "rightSlide", "destroyOnClose", "dialogClass", "beforeClose", "maxHeight", "dialogTransition", "customStyle", "noAnimation"]),
  model: {
    prop: "visible",
    event: "update:visible"
  },
  provide: function provide() {
    return {
      dialog: this
    };
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "duration": _vm.noAnimation ? 0 : void 0,
      "name": _vm.state.animationName
    },
    on: {
      "after-enter": _vm.afterEnter,
      "after-leave": _vm.afterLeave
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    class: ["tiny-dialog-box__wrapper", _vm.dialogClass],
    on: {
      "click": function click($event) {
        if ($event.target !== $event.currentTarget) return null;
        return _vm.handleWrapperClick.apply(null, arguments);
      },
      "mouseup": _vm.useMouseEventUp,
      "mousedown": _vm.useMouseEventDown
    }
  }, [_c("transition", {
    attrs: {
      "name": _vm.dialogTransition
    }
  }, [(_vm.destroyOnClose ? _vm.visible : true) ? _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    key: _vm.state.key,
    ref: "dialog",
    staticClass: "tiny-dialog-box",
    class: [{
      "is-fullscreen": _vm.state.isFull,
      "is-center": _vm.center,
      "is-right-slide": _vm.rightSlide
    }],
    style: _vm.state.style,
    attrs: {
      "data-tag": "tiny-dialog-box",
      "data-dialog-box-draggable": _vm.draggable
    }
  }, [_vm.showHeader ? _c("div", {
    ref: "header",
    staticClass: "tiny-dialog-box__header",
    on: {
      "mousedown": _vm.handleDrag
    }
  }, [_vm._t("title", function() {
    return [_c("span", {
      staticClass: "tiny-dialog-box__title"
    }, [_vm._v(_vm._s(_vm.title))])];
  }), _c("div", {
    staticClass: "tiny-dialog-box__btn-tools"
  }, [_vm.resize && !_vm.state.isFull ? _c("button", {
    staticClass: "tiny-dialog-box__headerbtn",
    attrs: {
      "type": "button",
      "aria-label": "Resize"
    },
    on: {
      "click": function click($event) {
        return _vm.toggleFullScreen(true);
      }
    }
  }, [_c("icon-fullscreen", {
    staticClass: "tiny-svg-size tiny-dialog-box__resize"
  })], 1) : _vm._e(), _vm.resize && _vm.state.isFull ? _c("button", {
    staticClass: "tiny-dialog-box__headerbtn",
    attrs: {
      "type": "button",
      "aria-label": "Resize"
    },
    on: {
      "click": function click($event) {
        return _vm.toggleFullScreen(false);
      }
    }
  }, [_c("icon-minscreen", {
    staticClass: "tiny-svg-size tiny-dialog-box__resize"
  })], 1) : _vm._e(), _vm.showClose ? _c("button", {
    staticClass: "tiny-dialog-box__headerbtn",
    attrs: {
      "type": "button",
      "aria-label": "Close"
    },
    on: {
      "click": function click($event) {
        return _vm.handleClose("close", $event);
      }
    }
  }, [_c("icon-close", {
    staticClass: "tiny-svg-size tiny-dialog-box__close"
  })], 1) : _vm._e()])], 2) : _vm._e(), _c("div", {
    staticClass: "tiny-dialog-box__body"
  }, [_vm._t("default")], 2), _vm.slots.footer ? _c("div", {
    ref: "footer",
    staticClass: "tiny-dialog-box__footer"
  }, [_vm._t("footer", null, {
    "beforeClose": _vm.beforeClose
  })], 2) : _vm._e()]) : _vm._e()])], 1)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
